@@ -197,7 +197,6 @@ bool CertificateAuthority::writeCertificate(const char *commonname, X509 *newCer
     std::string path(caser->filename);
     std::string dirpath(caser->filepath);
 
-    //mode_t old_umask;
     // make directory path
     int rc = mkpath(dirpath.c_str(), 0700); // only want e2g to have access to these dir
     if (rc != 0) {
@@ -275,13 +274,6 @@ bool CertificateAuthority::writeCertificate(const char *commonname, X509 *newCer
         fclose(fp);
         return false;
     }
-    // Symlinks no longer used
-    //if(symlink((_certPath + filename).c_str(),
-    //(_certLinks + filename).c_str()) < 0){
-    //syslog(LOG_ERR,"couldnt create link to certificate");
-    //fclose(fp);
-    //exit(1);
-    //}
 
     //unlock the file
     fl.l_type = F_UNLCK;
@@ -378,7 +370,7 @@ X509 *CertificateAuthority::generateCertificate(const char *commonname, struct c
         std::cout  << thread_id << "NAME_add_entry_by_txt on cert failed for " << commonname << std::endl;
 #endif
         log_ssl_errors("NAME_add_entry_by_txt on cert failed for %s", commonname);
-        X509_NAME_free(name);
+    //    X509_NAME_free(name);
         X509_free(newCert);
         return NULL;
     }
@@ -401,7 +393,7 @@ X509 *CertificateAuthority::generateCertificate(const char *commonname, struct c
         std::cout  << thread_id << "set_issuer_name on cert failed for " << commonname << std::endl;
 #endif
         log_ssl_errors("set_issuer_name on cert failed for %s", commonname);
-        X509_NAME_free(subjectName);
+     //   X509_NAME_free(subjectName);
         X509_free(newCert);
         return NULL;
     }
