@@ -43,6 +43,7 @@
 #ifdef __SSLMITM
 #include <openssl/ssl.h>
 #include <openssl/err.h>
+#include <openssl/conf.h>
 #endif //__SSLMITM
 
 #include "FatController.hpp"
@@ -265,7 +266,7 @@ static void kill_ssl_locks(void)
   OPENSSL_free(ssl_lock_array);
 }
 #endif
-#endif
+#endif   //end __SSLMITM
 
 void monitor_flag_set(bool action)
 {
@@ -1306,9 +1307,12 @@ void accept_connections(int index) // thread to listen on a single listening soc
         thread_id += ": ";
         while ((errorcount < 30) && !ttg) {
             Socket *peersock = serversockets[index]->accept();
-            if (ttg) break;
             int err = serversockets[index]->getErrno();
             if (err == 0 && peersock != NULL && peersock->getFD() > -1) {
+            	if (ttg) {
+			delete peersock;
+			break;
+		}
 #ifdef DGDEBUG
                 std::cerr << thread_id << "got connection from accept" << std::endl;
 #endif
@@ -1322,6 +1326,10 @@ void accept_connections(int index) // thread to listen on a single listening soc
                 std::cerr << thread_id << "pushed connection to http_worker_Q" << std::endl;
 #endif
             } else {
+            	if (ttg) {
+			if (peersock != nullptr) delete peersock;
+			break;
+		}
 #ifdef DGDEBUG
                 std::cerr << thread_id << "Error on accept: errorcount " << errorcount << " errno: " << err << std::endl;
 #endif
@@ -1533,11 +1541,24 @@ int fc_controlit()   //
     SSL_load_error_strings();
     OpenSSL_add_all_algorithms();
     OpenSSL_add_all_digests();
+    if (o.use_openssl_conf) {
+    	if(o.have_openssl_conf) {
+		if (CONF_modules_load_file(o.openssl_conf_path.c_str(), nullptr,0) != 1) {
+		syslog(LOG_ERR, "Error reading openssl config file %s", o.openssl_conf_path.c_str());
+		return false;
+		}
+	} else {
+		if (CONF_modules_load_file(nullptr, nullptr,0) != 1) {
+		syslog(LOG_ERR, "Error reading default openssl config files");
+		return false;
+		}
+	}
+    }
     SSL_library_init();
 #if OPENSSL_VERSION_NUMBER < 0x10100000L
     init_ssl_locks();
 #endif
-#endif
+#endif  // end __SSLMITM
 
     // this has to be done after daemonise to ensure we get the correct PID.
     rc = sysv_writepidfile(pidfilefd); // also closes the fd
