@@ -219,6 +219,18 @@ bool OptionContainer::read(std::string& filename, int type)
 
        if(enable_ssl) {
         bool ret = true;
+	if (findoptionS("useopensslconf") == "on") {
+		use_openssl_conf = true;
+		openssl_conf_path = findoptionS("opensslconffile");
+		if (openssl_conf_path == "") {
+			have_openssl_conf = false;
+		} else {
+			have_openssl_conf = true;
+		}
+	} else {
+		use_openssl_conf = false;
+	};
+
         ca_certificate_path = findoptionS("cacertificatepath");
         if (ca_certificate_path == "") {
 		   if (!is_daemonised){
@@ -269,7 +281,6 @@ bool OptionContainer::read(std::string& filename, int type)
         if (set_cipher_list == "")
             set_cipher_list = "HIGH:!ADH:!MD5:!RC4:!SRP:!PSK:!DSS";
 
-//        if (ca_certificate_path != "" )
         if (ret) {
             	ca = new CertificateAuthority(ca_certificate_path.c_str(),
                 ca_private_key_path.c_str(),
@@ -557,6 +568,23 @@ bool OptionContainer::read(std::string& filename, int type)
             syslog(LOG_ERR, "%s", "Can not listen on more than 127 IPs");
             return false;
         }
+        // multiple check IP support - used for loop checking
+        check_ip = findoptionM("checkip");
+        if (check_ip.size() > 127) {
+            if (!is_daemonised) {
+                std::cerr << "Can not check on more than 127 IPs" << std::endl;
+            }
+            syslog(LOG_ERR, "%s", "Can not check on more than 127 IPs");
+            return false;
+        }
+        //if (check_ip.size() == 0) {   // set defaults
+            //if (filter_ip.size() > 0) {
+            //    check_ip = filter_ip;
+            //} else {
+            //    String t = "127.0.0.1";
+            //    check_ip.push_back(t);
+            //}
+        //}
         filter_ports = findoptionM("filterports");
         if (map_ports_to_ips and filter_ports.size() != filter_ip.size()) {
             if (!is_daemonised) {
@@ -894,12 +922,6 @@ bool OptionContainer::read(std::string& filename, int type)
         } // messages language file
 
 
- //       if(!createLists(0))  {
- //               std::cerr << "Error reading filter group conf file(s)." << std::endl;
-//            syslog(LOG_ERR, "%s", "Error reading filter group conf file(s).");
-//            return false;
-//        }
-
 
 #ifdef _SSLMITM
         if (enable_ssl) {
@@ -929,27 +951,6 @@ bool OptionContainer::read(std::string& filename, int type)
     return true;
 }
 
-// read from stdin, write the list's ID into the given identifier,
-// sort using startsWith or endsWith depending on sortsw
-// listname is used in error messages.
-#ifdef NOTDEF
-bool OptionContainer::readStdin(ListContainer *lc, bool sortsw, const char *listname )
-{
-    bool result = lc->readStdinItemList(sortsw, 1);
-    if (!result) {
-        if (!is_daemonised) {
-            std::cerr << "Error opening " << listname << std::endl;
-        }
-        syslog(LOG_ERR, "Error opening %s", listname);
-        return false;
-    }
-    if (sortsw)
-        lc->doSort(true);
-    else
-        lc->doSort(false);
-    return true;
-}
-#endif
 
 bool OptionContainer::readinStdin()
 {
