@@ -88,6 +88,7 @@ class OptionContainer
     std::string icap_resmod_url;
     std::string proxy_ip;
     std::deque<String> filter_ip;
+    std::deque<String> check_ip;
     std::deque<String> filter_ports;
     std::map<int, String> auth_map;
     bool abort_on_missing_list = false;
@@ -170,7 +171,10 @@ class OptionContainer
     std::string cert_private_key_path;
     std::string generated_cert_path;
     std::string generated_link_path;
+    std::string openssl_conf_path;
     CertificateAuthority *ca;
+    bool use_openssl_conf = false;
+    bool have_openssl_conf = false;
 #endif
     std::string set_cipher_list;
 
